render_markdown

Function render_markdown 

pub fn render_markdown() -> String
Render the keyword reference page — three tiers, each with prose that is true of that tier (the page used to make one blanket claim that was false of two of them).